@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "objc-font-lock" "0.0.5"
+(define-package "objc-font-lock" "20250103.1606"
   "Highlight Objective-C method calls."
   ()
   :url "https://github.com/Lindydancer/objc-font-lock"
